@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::XSLT;
-$XML::GrammarBase::Role::XSLT::VERSION = '0.2.7';
+$XML::GrammarBase::Role::XSLT::VERSION = '0.2.8';
 use strict;
 use warnings;
 
@@ -52,7 +52,7 @@ XML::GrammarBase::Role::XSLT - a parameterized role for XSLT conversions.
 
 =head1 VERSION
 
-version 0.2.7
+version 0.2.8
 
 =head1 SYNOPSIS
 
@@ -179,47 +179,6 @@ L<Package::Variant> constructor. For internal use.
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-xml-grammarbase at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-GrammarBase>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 THANKS
-
-Thanks to Matt S. Trout L<http://metacpan.org/author/MSTROUT> and other
-people from #moose on irc.perl.org for helping me figure out
-L<Moo> / L<MooX> and steer me away from L<Any::Moose> , and for writing
-the L<Moo> ecosystem.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc XML::GrammarBase
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-GrammarBase>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/XML-GrammarBase>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/XML-GrammarBase>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/XML-GrammarBase/>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 =head1 COPYRIGHT & LICENSE
@@ -250,37 +209,10 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2018 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-XML-GrammarBase/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc XML::GrammarBase::Role::XSLT
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -298,14 +230,6 @@ L<https://metacpan.org/release/XML-GrammarBase>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/XML-GrammarBase>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -314,14 +238,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/XML-GrammarBase>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -370,4 +286,25 @@ L<https://github.com/shlomif/perl-XML-GrammarBase>
 
   git clone git://github.com/shlomif/perl-XML-GrammarBase.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-XML-GrammarBase/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
